DioHelper class

Constructors

DioHelper(Dio _dio)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelRequests(CancelToken token) → void
logInterceptor() → List<Interceptor>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<T>(String baseUrl, {DioMethod dioMethod = DioMethod.get, String? path = '', dynamic data, Map<String, dynamic>? queryParameter, Options? options, Map<String, dynamic>? header}) → Future
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited